pub enum What {
FileVersion(String),
GraphDef(Vec<u8>),
Summary(Summary),
LogMessage(LogMessage),
SessionLog(SessionLog),
TaggedRunMetadata(TaggedRunMetadata),
MetaGraphDef(Vec<u8>),
}Variants
FileVersion(String)
An event file was started, with the specified version. This is use to identify the contents of the record IO files easily. Current version is “brain.Event:2”. All versions start with “brain.Event:”.
GraphDef(Vec<u8>)
An encoded version of a GraphDef.
Summary(Summary)
A summary was generated.
LogMessage(LogMessage)
The user output a log message. This was theoretically used by the defunct tensorboard_logging module, which has since been removed; this field is now deprecated and should not be used.
SessionLog(SessionLog)
The state of the session which can be used for restarting after crashes.
TaggedRunMetadata(TaggedRunMetadata)
The metadata returned by running a session.run() call.
MetaGraphDef(Vec<u8>)
An encoded version of a MetaGraphDef.
Implementations
Sourceimpl What
impl What
Sourcepub fn merge<B>(
field: &mut Option<What>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<What>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.