#[repr(i32)]pub enum OptimizationSource {
SourceUnspecified = 0,
Aot = 1,
Jit = 2,
}Expand description
Enum for distinguishing the origin where the proto is created.
AOT: proto is created in ahead-of-time environment, which can be different from the environment where the graph is actually executed.
JIT: proto is created in just-in-time execution, which has the same environment as the one the graph is actually executed.
Variants
Implementations
Sourceimpl OptimizationSource
impl OptimizationSource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.