pub struct OptimizedFunctionGraph {
pub name: String,
pub function_graph: Option<GraphDef>,
pub node_name_to_control_ret: HashMap<String, String>,
pub ret_types: Vec<i32>,
pub num_return_nodes: u32,
pub source: Option<i32>,
pub optimization_time_usecs: Option<u64>,
}Expand description
Optimized function graph after instantiation-related graph optimization passes (up till before graph partitioning). The first half of the proto is representing a GraphDef and the rest of the fields are extra information from graph optimizations.
Fields
name: StringFunction name. It can be a human-readable SignatureDef’s method name, or a FunctionDef name.
function_graph: Option<GraphDef>Optimized function graph.
node_name_to_control_ret: HashMap<String, String>Maps from node name to control ret. This is an output from running TF/XLA bridge.
ret_types: Vec<i32>Return node types of the function. This is an output of graph preprocessing.
num_return_nodes: u32Number of return nodes. This is an output of graph preprocessing.
source: Option<i32>Indicates the source environment where this proto is generated.
optimization_time_usecs: Option<u64>Time (in microseconds) spent on running the graph optimization passes for this function.
Implementations
Sourceimpl OptimizedFunctionGraph
impl OptimizedFunctionGraph
Sourcepub fn ret_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<DataType>>
pub fn ret_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<DataType>>
Returns an iterator which yields the valid enum values contained in ret_types.
Sourcepub fn push_ret_types(&mut self, value: DataType)
pub fn push_ret_types(&mut self, value: DataType)
Appends the provided enum value to ret_types.
Sourcepub fn source(&self) -> OptimizationSource
pub fn source(&self) -> OptimizationSource
Returns the enum value of source, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_source(&mut self, value: OptimizationSource)
pub fn set_source(&mut self, value: OptimizationSource)
Sets source to the provided enum value.
Sourcepub fn optimization_time_usecs(&self) -> u64
pub fn optimization_time_usecs(&self) -> u64
Returns the value of optimization_time_usecs, or the default value if optimization_time_usecs is unset.