SummaryMetadata

Struct SummaryMetadata 

pub struct SummaryMetadata {
    pub plugin_data: Option<PluginData>,
    pub display_name: String,
    pub summary_description: String,
    pub data_class: i32,
}
A SummaryMetadata encapsulates information on which plugins are able to make use of a certain summary value.

Fields

plugin_data: Option<PluginData>

Data that associates a summary with a certain plugin.

display_name: String

Display name for viewing in TensorBoard.

summary_description: String

Longform readable description of the summary sequence. Markdown supported.

data_class: i32

Class of data stored in this time series. Required for compatibility with TensorBoard’s generic data facilities (DataProvider, et al.). This value imposes constraints on the dtype and shape of the corresponding tensor values. See DataClass docs for details.

Implementations

Source

impl SummaryMetadata

pub fn data_class(&self) -> DataClass

Returns the enum value of data_class, or the default if the field is set to an invalid enum value.

pub fn set_data_class(&mut self, value: DataClass)

Sets data_class to the provided enum value.